@@ -3,6 +3,9 @@ from datetime import datetime, date, time
 from bson.objectid import ObjectId
 from mongoengine.document import Document
 from mongoengine.queryset import QuerySet
+from pymongo import dbref
+from mongoengine import base
+import j25
 
 class JSONCustomEncoder(JSONEncoder):
     def default(self, obj):
@@ -16,6 +19,9 @@ class JSONCustomEncoder(JSONEncoder):
             except:
                 pass
             return doc
+        if isinstance(obj, dbref.DBRef):
+            doc = j25._store[obj.collection].find_one({'_id': ObjectId(obj.id)})
+            return doc
         if isinstance(obj, ObjectId):
             return str(obj)
         elif isinstance(obj, datetime):
